@@ -102,37 +102,37 @@ def main():
                       default='no',
                       help="if you want to use all card types Use 'yes'/'y' ")
   
-  parser.add_argument('-conn',
+  parser.add_argument('--conn',
                       type=str, 
                       default=None,
                       help="if you want to insert this data in Mongo database kindly enter the correct connection string")
   
-  parser.add_argument('-filepath',
+  parser.add_argument('--filepath',
                       type=str, 
                       default=None,
                       help="if you want data in json file than provide the path where you want it.")
   
-  parser.add_argument('-cl',
+  parser.add_argument('--cl',
                       type=str,
                       default='no',
                       help="If you want to insert data in cloud's database than enter yes/y ")
-  parser.add_argument('-cloud_name',
+  parser.add_argument('--cloud_name',
                       type=str,
                       default=None,
                       help="Enter the cloud name available clouds are [azure, gcp]")
                                           
-  parser.add_argument('-db_type',
+  parser.add_argument('--db_type',
                       type=str,
                       default=None,
                       help="Enter the db_type name available clouds are Azure = ['maria', 'sql', 'mysql', 'psql'] GCP=[sql, mysql, psql]")
 
-  parser.add_argument('-json_path',
+  parser.add_argument('--json_path',
                       type=str,
                       default=None,
                       help="enter the config file path that have the credentials of database (file format json is needed)")
 
   
-  args = parser.parse_args()
+  args, unknown = parser.parse_known_args()
 
   print("============"*5)
   pprint(get_cli_pii_data(args))
